@@ -76,6 +76,7 @@
 #include <qdir.h>
 #include <qevent.h>
 #include <qlibraryinfo.h>
+#include <qmessagebox.h>
 #include <qsettings.h>
 #include <qtextstream.h>
 #include <qtranslator.h>
@@ -96,11 +97,18 @@ BookmarksManager *BrowserApplication::s_bookmarksManager = 0;
 BrowserApplication::BrowserApplication(int &argc, char **argv)
     : QApplication(argc, argv)
     , m_localServer(0)
+    , quiting(false)
 {
     QCoreApplication::setOrganizationDomain(QLatin1String("arora-browser.org"));
     QCoreApplication::setApplicationName(QLatin1String("Arora"));
-    QString version = QString("0.2 (Change: %1 %2)").arg(GITCHANGENUMBER).arg(GITVERSION);
+    QString version = QLatin1String("0.4");
+    if (QLatin1String(GITCHANGENUMBER) != QLatin1String("0"))
+        version += QString(tr(" (Change: %1 %2)"))
+                    .arg(QLatin1String(GITCHANGENUMBER))
+                    .arg(QLatin1String(GITVERSION));
+
     QCoreApplication::setApplicationVersion(version);
+#ifndef AUTOTESTS
 #ifdef Q_WS_QWS
     // Use a different server name for QWS so we can run an X11
     // browser and a QWS browser in parallel on the same machine for
@@ -108,7 +116,7 @@ BrowserApplication::BrowserApplication(int &argc, char **argv)
     QString serverName = QCoreApplication::applicationName() + QLatin1String("_qws");
 #else
     QString serverName = QCoreApplication::applicationName();
-#endif
+#endif // Q_WS_QWS
     QLocalSocket socket;
     socket.connectToServer(serverName);
     if (socket.waitForConnected(500)) {
@@ -123,12 +131,6 @@ BrowserApplication::BrowserApplication(int &argc, char **argv)
         return;
     }
 
-#if defined(Q_WS_MAC)
-    QApplication::setQuitOnLastWindowClosed(false);
-#else
-    QApplication::setQuitOnLastWindowClosed(true);
-#endif
-
     m_localServer = new QLocalServer(this);
     connect(m_localServer, SIGNAL(newConnection()),
             this, SLOT(newLocalSocketConnection()));
@@ -139,12 +141,19 @@ BrowserApplication::BrowserApplication(int &argc, char **argv)
             m_localServer->listen(serverName);
         }
     }
+#endif // AUTOTESTS
+
+#if defined(Q_WS_MAC)
+    QApplication::setQuitOnLastWindowClosed(false);
+#else
+    QApplication::setQuitOnLastWindowClosed(true);
+#endif
 
     QDesktopServices::setUrlHandler(QLatin1String("http"), this, "openUrl");
     QString localSysName = QLocale::system().name();
 
     installTranslator(QLatin1String("qt_") + localSysName);
-    installTranslator(dataDirectory() + QDir::separator() + "locale" + QDir::separator() + localSysName);
+    installTranslator(dataDirectory() + QDir::separator() + QLatin1String("locale") + QDir::separator() + localSysName);
 
     // Until QtWebkit defaults to 16
     QWebSettings::globalSettings()->setFontSize(QWebSettings::DefaultFontSize, 16);
@@ -160,11 +169,14 @@ BrowserApplication::BrowserApplication(int &argc, char **argv)
             this, SLOT(lastWindowClosed()));
 #endif
 
+#ifndef AUTOTESTS
     QTimer::singleShot(0, this, SLOT(postLaunch()));
+#endif // AUTOTESTS
 }
 
 BrowserApplication::~BrowserApplication()
 {
+    quiting = true;
     delete s_downloadManager;
     qDeleteAll(m_mainWindows);
     delete s_networkAccessManager;
@@ -206,6 +218,7 @@ void BrowserApplication::quitBrowser()
             return;
     }
 
+    saveSession();
     exit(0);
 }
 #endif
@@ -226,11 +239,35 @@ void BrowserApplication::postLaunch()
 
     // newMainWindow() needs to be called in main() for this to happen
     if (m_mainWindows.count() > 0) {
+        QSettings settings;
+        settings.beginGroup(QLatin1String("MainWindow"));
+        int startup = settings.value(QLatin1String("startupBehavior")).toInt();
         QStringList args = QCoreApplication::arguments();
-        if (args.count() > 1)
-            mainWindow()->loadPage(args.last());
-        else
-            mainWindow()->slotHome();
+
+        if (args.count() > 1) {
+            switch (startup) {
+            case 2: {
+                restoreLastSession();
+                WebView *webView = mainWindow()->tabWidget()->makeNewTab(true);
+                webView->loadUrl(args.last());
+                break;
+            }
+            default:
+                mainWindow()->loadPage(args.last());
+                break;
+            }
+        } else {
+            switch (startup) {
+            case 0:
+                mainWindow()->slotHome();
+                break;
+            case 1:
+                break;
+            case 2:
+                restoreLastSession();
+                break;
+            }
+        }
     }
     BrowserApplication::historyManager();
 }
@@ -247,6 +284,9 @@ void BrowserApplication::loadSettings()
     standardFont = qVariantValue<QFont>(settings.value(QLatin1String("standardFont"), standardFont));
     defaultSettings->setFontFamily(QWebSettings::StandardFont, standardFont.family());
     defaultSettings->setFontSize(QWebSettings::DefaultFontSize, standardFont.pointSize());
+    int minimumFontSize = settings.value(QLatin1String("minimumFontSize"),
+                defaultSettings->fontSize(QWebSettings::MinimumFontSize)).toInt();
+    defaultSettings->setFontSize(QWebSettings::MinimumFontSize, minimumFontSize);
 
     QString fixedFontFamily = defaultSettings->fontFamily(QWebSettings::FixedFont);
     int fixedFontSize = defaultSettings->fontSize(QWebSettings::DefaultFixedFontSize);
@@ -258,6 +298,7 @@ void BrowserApplication::loadSettings()
     defaultSettings->setAttribute(QWebSettings::JavascriptEnabled, settings.value(QLatin1String("enableJavascript"), true).toBool());
     defaultSettings->setAttribute(QWebSettings::PluginsEnabled, settings.value(QLatin1String("enablePlugins"), true).toBool());
     defaultSettings->setAttribute(QWebSettings::AutoLoadImages, settings.value(QLatin1String("enableImages"), true).toBool());
+    defaultSettings->setAttribute(QWebSettings::DeveloperExtrasEnabled, settings.value(QLatin1String("enableInspector"), false).toBool());
 
     QUrl url = settings.value(QLatin1String("userStyleSheet")).toUrl();
     defaultSettings->setUserStyleSheetUrl(url);
@@ -286,13 +327,19 @@ static const qint32 BrowserApplicationMagic = 0xec;
 
 void BrowserApplication::saveSession()
 {
+    if (quiting)
+        return;
+    QSettings settings;
+    settings.beginGroup(QLatin1String("MainWindow"));
+    settings.setValue(QLatin1String("restoring"), false);
+    settings.endGroup();
+
     QWebSettings *globalSettings = QWebSettings::globalSettings();
     if (globalSettings->testAttribute(QWebSettings::PrivateBrowsingEnabled))
         return;
 
     clean();
 
-    QSettings settings;
     settings.beginGroup(QLatin1String("sessions"));
 
     int version = 2;
@@ -319,6 +366,18 @@ bool BrowserApplication::canRestoreSession() const
 
 bool BrowserApplication::restoreLastSession()
 {
+    {
+        QSettings settings;
+        settings.beginGroup(QLatin1String("MainWindow"));
+        if (settings.value(QLatin1String("restoring"), false).toBool()) {
+            QMessageBox::information(0, tr("Restore failed"),
+                tr("The saved session will not be restored because Arora crashed while trying to restore this session."));
+            return false;
+        }
+        // saveSession will be called by an AutoSaver timer from the set tabs
+        // and in saveSession we will reset this flag back to false
+        settings.setValue(QLatin1String("restoring"), true);
+    }
     int version = 2;
     QList<QByteArray> windows;
     QBuffer buffer(&m_lastSession);
@@ -341,9 +400,7 @@ bool BrowserApplication::restoreLastSession()
     }
     for (int i = 0; i < windows.count(); ++i) {
         BrowserMainWindow *newWindow = 0;
-        if (m_mainWindows.count() == 1
-            && mainWindow()->tabWidget()->count() == 1
-            && mainWindow()->currentTab()->url() == QUrl()) {
+        if (i == 0 && m_mainWindows.count() >= 1) {
             newWindow = mainWindow();
         } else {
             newWindow = newMainWindow();
@@ -493,7 +550,7 @@ QIcon BrowserApplication::icon(const QUrl &url)
 QString BrowserApplication::dataDirectory() const
 {
 #if defined(Q_WS_X11)
-    return PKGDATADIR;
+    return QLatin1String(PKGDATADIR);
 #else
     return applicationDirPath();
 #endif
