@@ -1,6 +1,7 @@
 /*
  * Copyright 2008 Benjamin C. Meyer <ben@meyerhome.net>
  * Copyright 2008 Jason A. Donenfeld <Jason@zx2c4.com>
+ * Copyright 2008 Ariya Hidayat <ariya.hidayat@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,7 +75,6 @@
 #include "tabbar.h"
 #include "tabwidget.h"
 #include "toolbarsearch.h"
-#include "ui_passworddialog.h"
 #include "webview.h"
 #include "webviewsearch.h"
 
@@ -123,8 +123,33 @@ BrowserMainWindow::BrowserMainWindow(QWidget *parent, Qt::WindowFlags flags)
     layout->setSpacing(0);
     layout->setMargin(0);
 #if defined(Q_WS_MAC)
+    m_bookmarksToolbarFrame = new QFrame(this);
+    m_bookmarksToolbarFrame->setLineWidth(1);
+    m_bookmarksToolbarFrame->setMidLineWidth(0);
+    m_bookmarksToolbarFrame->setFrameShape(QFrame::HLine);
+    m_bookmarksToolbarFrame->setFrameShadow(QFrame::Raised);
+    QPalette fp = m_bookmarksToolbarFrame->palette();
+    fp.setColor(QPalette::Active, QPalette::Light, QColor(64, 64, 64));
+    fp.setColor(QPalette::Active, QPalette::Dark, QColor(192, 192, 192));
+    fp.setColor(QPalette::Inactive, QPalette::Light, QColor(135, 135, 135));
+    fp.setColor(QPalette::Inactive, QPalette::Dark, QColor(226, 226, 226));
+    m_bookmarksToolbarFrame->setAttribute(Qt::WA_MacNoClickThrough, true);
+    m_bookmarksToolbarFrame->setPalette(fp);
+    layout->addWidget(m_bookmarksToolbarFrame);
+
     layout->addWidget(m_bookmarksToolbar);
-    layout->addWidget(new QWidget); // <- OS X tab widget style bug
+    QPalette p = m_bookmarksToolbar->palette();
+    p.setColor(QPalette::Active, QPalette::Window, QColor(150, 150, 150));
+    p.setColor(QPalette::Inactive, QPalette::Window, QColor(207, 207, 207));
+    m_bookmarksToolbar->setAttribute(Qt::WA_MacNoClickThrough, true);
+    m_bookmarksToolbar->setAutoFillBackground(true);
+    m_bookmarksToolbar->setPalette(p);
+    m_bookmarksToolbar->setBackgroundRole(QPalette::Window);
+    m_bookmarksToolbar->setMaximumHeight(19);
+
+    QWidget *w = new QWidget(this);
+    w->setMaximumHeight(0);
+    layout->addWidget(w); // <- OS X tab widget style bug
 #else
     addToolBarBreak();
     addToolBar(m_bookmarksToolbar);
@@ -163,9 +188,8 @@ BrowserMainWindow::BrowserMainWindow(QWidget *parent, Qt::WindowFlags flags)
     slotUpdateWindowTitle();
     loadDefaultState();
     m_tabWidget->newTab();
-
-    int size = m_tabWidget->lineEditStack()->sizeHint().height();
-    m_navigationBar->setIconSize(QSize(size, size));
+    m_tabWidget->currentLineEdit()->setFocus();
+    m_navigationBar->setIconSize(QSize(18, 18));
 
     // Add each item in the menu bar to the main window so
     // if the menu bar is hidden the shortcuts still work.
@@ -175,6 +199,9 @@ BrowserMainWindow::BrowserMainWindow(QWidget *parent, Qt::WindowFlags flags)
             actions += action->menu()->actions();
         addAction(action);
     }
+#if defined(Q_WS_MAC)
+    setWindowIcon(QIcon());
+#endif
 }
 
 BrowserMainWindow::~BrowserMainWindow()
@@ -231,6 +258,9 @@ QByteArray BrowserMainWindow::saveState(bool withTabs) const
         stream << QByteArray();
     stream << m_navigationSplitter->saveState();
     stream << m_tabWidget->tabBar()->showTabBarWhenOneTab();
+
+    stream << qint32(toolBarArea(m_navigationBar));
+    stream << qint32(toolBarArea(m_bookmarksToolbar));
     return data;
 }
 
@@ -256,6 +286,8 @@ bool BrowserMainWindow::restoreState(const QByteArray &state)
     QByteArray tabState;
     QByteArray splitterState;
     bool showTabBarWhenOneTab;
+    qint32 navigationBarLocation;
+    qint32 bookmarkBarLocation;
 
     stream >> size;
     stream >> showToolbar;
@@ -264,6 +296,8 @@ bool BrowserMainWindow::restoreState(const QByteArray &state)
     stream >> tabState;
     stream >> splitterState;
     stream >> showTabBarWhenOneTab;
+    stream >> navigationBarLocation;
+    stream >> bookmarkBarLocation;
 
     resize(size);
 
@@ -271,6 +305,9 @@ bool BrowserMainWindow::restoreState(const QByteArray &state)
     updateToolbarActionText(showToolbar);
 
     m_bookmarksToolbar->setVisible(showBookmarksBar);
+#if defined(Q_WS_MAC)
+    m_bookmarksToolbarFrame->setVisible(showBookmarksBar);
+#endif
     updateBookmarksToolbarActionText(showBookmarksBar);
 
     statusBar()->setVisible(showStatusbar);
@@ -283,6 +320,13 @@ bool BrowserMainWindow::restoreState(const QByteArray &state)
 
     m_tabWidget->tabBar()->setShowTabBarWhenOneTab(showTabBarWhenOneTab);
 
+    Qt::ToolBarArea navigationArea = Qt::ToolBarArea(navigationBarLocation);
+    if (navigationArea != Qt::TopToolBarArea && navigationArea != Qt::NoToolBarArea)
+        addToolBar(navigationArea, m_navigationBar);
+    Qt::ToolBarArea bookmarkArea = Qt::ToolBarArea(bookmarkBarLocation);
+    if (bookmarkArea != Qt::TopToolBarArea && bookmarkArea != Qt::NoToolBarArea)
+        addToolBar(bookmarkArea, m_bookmarksToolbar);
+
     return true;
 }
 
@@ -351,21 +395,21 @@ void BrowserMainWindow::setupMenu()
     connect(m_find, SIGNAL(triggered()), this, SLOT(slotEditFind()));
     new QShortcut(QKeySequence(Qt::Key_Slash), this, SLOT(slotEditFind()));
 
-    QAction *m_findNext = editMenu->addAction(tr("&Find Next"));
+    QAction *m_findNext = editMenu->addAction(tr("Find Nex&t"));
     m_findNext->setShortcuts(QKeySequence::FindNext);
     connect(m_findNext, SIGNAL(triggered()), this, SLOT(slotEditFindNext()));
 
-    QAction *m_findPrevious = editMenu->addAction(tr("&Find Previous"));
+    QAction *m_findPrevious = editMenu->addAction(tr("Find P&revious"));
     m_findPrevious->setShortcuts(QKeySequence::FindPrevious);
     connect(m_findPrevious, SIGNAL(triggered()), this, SLOT(slotEditFindPrevious()));
 
     editMenu->addSeparator();
-    editMenu->addAction(tr("&Preferences"), this, SLOT(slotPreferences()), tr("Ctrl+,"));
+    editMenu->addAction(tr("Prefere&nces..."), this, SLOT(slotPreferences()), tr("Ctrl+,"));
 
     // View
     QMenu *viewMenu = menuBar()->addMenu(tr("&View"));
-    m_showMenuBarAction = new QAction("Show Menu Bar", this);
-    m_showMenuBarAction->setShortcut(QKeySequence("Ctrl+m"));
+    m_showMenuBarAction = new QAction(tr("Show Menu Bar"), this);
+    m_showMenuBarAction->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_M));
     connect(m_showMenuBarAction, SIGNAL(triggered()), this, SLOT(slotViewMenuBar()));
     addAction(m_showMenuBarAction);
 
@@ -401,13 +445,13 @@ void BrowserMainWindow::setupMenu()
     m_stop->setShortcuts(shortcuts);
     m_tabWidget->addWebAction(m_stop, QWebPage::Stop);
 
-    m_reload = viewMenu->addAction(tr("Reload Page"));
+    m_reload = viewMenu->addAction(tr("&Reload Page"));
     m_reload->setShortcuts(QKeySequence::Refresh);
     m_tabWidget->addWebAction(m_reload, QWebPage::Reload);
 
-    viewMenu->addAction(tr("&Make Text Bigger"), this, SLOT(slotViewTextBigger()), QKeySequence(Qt::CTRL | Qt::Key_Plus));
-    viewMenu->addAction(tr("&Make Text Normal"), this, SLOT(slotViewTextNormal()), QKeySequence(Qt::CTRL | Qt::Key_0));
-    viewMenu->addAction(tr("&Make Text Smaller"), this, SLOT(slotViewTextSmaller()), QKeySequence(Qt::CTRL | Qt::Key_Minus));
+    viewMenu->addAction(tr("Make Text &Bigger"), this, SLOT(slotViewTextBigger()), QKeySequence(Qt::CTRL | Qt::Key_Plus));
+    viewMenu->addAction(tr("Make Text &Normal"), this, SLOT(slotViewTextNormal()), QKeySequence(Qt::CTRL | Qt::Key_0));
+    viewMenu->addAction(tr("Make Text &Smaller"), this, SLOT(slotViewTextSmaller()), QKeySequence(Qt::CTRL | Qt::Key_Minus));
 
     viewMenu->addSeparator();
     viewMenu->addAction(tr("Page S&ource"), this, SLOT(slotViewPageSource()), tr("Ctrl+Alt+U"));
@@ -457,6 +501,7 @@ void BrowserMainWindow::setupMenu()
     QList<QAction*> bookmarksActions;
 
     QAction *showAllBookmarksAction = new QAction(tr("Manage Bookmarks..."), this);
+    showAllBookmarksAction->setShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_B));
     connect(showAllBookmarksAction, SIGNAL(triggered()), this, SLOT(slotShowBookmarksDialog()));
     m_addBookmark = new QAction(QIcon(QLatin1String(":addbookmark.png")), tr("Add Bookmark..."), this);
     m_addBookmark->setIconVisibleInMenu(false);
@@ -480,10 +525,14 @@ void BrowserMainWindow::setupMenu()
     toolsMenu->addAction(tr("&Clear Private Data"), this, SLOT(slotClearPrivateData()),
                          QKeySequence(tr("Ctrl+Shift+Delete", "Clear Private Data")));
 #ifndef Q_CC_MINGW
-    a = toolsMenu->addAction(tr("Enable Web &Inspector"), this, SLOT(slotToggleInspector(bool)));
-    a->setCheckable(true);
+    QAction *m_enableInspector = toolsMenu->addAction(tr("Enable Web &Inspector"), this, SLOT(slotToggleInspector(bool)));
+    m_enableInspector->setCheckable(true);
+    QSettings settings;
+    settings.beginGroup(QLatin1String("websettings"));
+    m_enableInspector->setChecked(settings.value(QLatin1String("enableInspector"), false).toBool());
 #endif
 
+    // Help
     QMenu *helpMenu = menuBar()->addMenu(tr("&Help"));
     helpMenu->addAction(tr("About &Qt"), qApp, SLOT(aboutQt()));
     helpMenu->addAction(tr("About &Arora"), this, SLOT(slotAboutApplication()));
@@ -574,10 +623,16 @@ void BrowserMainWindow::slotViewBookmarksBar()
 {
     if (m_bookmarksToolbar->isVisible()) {
         updateBookmarksToolbarActionText(false);
-        m_bookmarksToolbar->close();
+        m_bookmarksToolbar->hide();
+#if defined(Q_WS_MAC)
+        m_bookmarksToolbarFrame->hide();
+#endif
     } else {
         updateBookmarksToolbarActionText(true);
         m_bookmarksToolbar->show();
+#if defined(Q_WS_MAC)
+        m_bookmarksToolbarFrame->show();
+#endif
     }
     m_autoSaver->changeOccurred();
 }
@@ -612,9 +667,14 @@ void BrowserMainWindow::slotViewStatusbar()
 QUrl BrowserMainWindow::guessUrlFromString(const QString &string)
 {
     QString urlStr = string.trimmed();
-    QRegExp test(QLatin1String("^[a-zA-Z]+\\:.*"));
+
+    // check if the string is just a host with a port
+    QRegExp hostWithPort(QLatin1String("^[a-zA-Z\\.]+\\:[0-9]*$"));
+    if (hostWithPort.exactMatch(urlStr))
+        urlStr = QLatin1String("http://") + urlStr;
 
     // Check if it looks like a qualified URL. Try parsing it and see.
+    QRegExp test(QLatin1String("^[a-zA-Z]+\\:.*"));
     bool hasSchema = test.exactMatch(urlStr);
     if (hasSchema) {
         bool isAscii = true;
@@ -680,8 +740,8 @@ void BrowserMainWindow::slotFileSaveAs()
 
 void BrowserMainWindow::slotPreferences()
 {
-    SettingsDialog s(this);
-    s.exec();
+    SettingsDialog settingsDialog(this);
+    settingsDialog.exec();
 }
 
 void BrowserMainWindow::slotUpdateStatusbar(const QString &string)
@@ -809,6 +869,22 @@ void BrowserMainWindow::closeEvent(QCloseEvent *event)
     deleteLater();
 }
 
+void BrowserMainWindow::mousePressEvent(QMouseEvent *event)
+{
+	switch(event->button())
+	{
+	case Qt::XButton1:
+		m_historyBack->activate(QAction::Trigger);
+		break;
+	case Qt::XButton2:
+		m_historyForward->activate(QAction::Trigger);
+		break;
+	default:
+		QMainWindow::mousePressEvent(event);
+		break;
+	}
+}
+
 void BrowserMainWindow::slotEditFind()
 {
     tabWidget()->webViewSearch(m_tabWidget->currentIndex())->showFind();
@@ -828,21 +904,21 @@ void BrowserMainWindow::slotViewTextBigger()
 {
     if (!currentTab())
         return;
-    currentTab()->setTextSizeMultiplier(currentTab()->textSizeMultiplier() + 0.1);
+    currentTab()->zoomIn();
 }
 
 void BrowserMainWindow::slotViewTextNormal()
 {
     if (!currentTab())
         return;
-    currentTab()->setTextSizeMultiplier(1.0);
+    currentTab()->resetZoom();
 }
 
 void BrowserMainWindow::slotViewTextSmaller()
 {
     if (!currentTab())
         return;
-    currentTab()->setTextSizeMultiplier(currentTab()->textSizeMultiplier() - 0.1);
+    currentTab()->zoomOut();
 }
 
 void BrowserMainWindow::slotViewFullScreen(bool makeFullScreen)
@@ -877,8 +953,8 @@ void BrowserMainWindow::slotHome()
 
 void BrowserMainWindow::slotWebSearch()
 {
-    m_toolbarSearch->lineEdit()->selectAll();
-    m_toolbarSearch->lineEdit()->setFocus();
+    m_toolbarSearch->selectAll();
+    m_toolbarSearch->setFocus();
 }
 
 void BrowserMainWindow::slotClearPrivateData()
@@ -899,6 +975,9 @@ void BrowserMainWindow::slotToggleInspector(bool enable)
             m_tabWidget->reloadAllTabs();
         }
     }
+    QSettings settings;
+    settings.beginGroup(QLatin1String("websettings"));
+    settings.setValue(QLatin1String("enableInspector"), enable);
 }
 
 void BrowserMainWindow::slotSwapFocus()
