@@ -182,7 +182,7 @@ QString DownloadItem::saveFileName(const QString &directory) const
     // Move this function into QNetworkReply to also get file name sent from the server
     QString path;
     if (m_reply->hasRawHeader("Content-Disposition")) {
-        QString value = m_reply->rawHeader("Content-Disposition");
+        QString value = QLatin1String(m_reply->rawHeader("Content-Disposition"));
         int pos = value.indexOf(QLatin1String("filename="));
         if (pos != -1) {
             QString name = value.mid(pos + 9);
@@ -261,7 +261,7 @@ void DownloadItem::downloadReadyRead()
         if (!m_requestFileName)
             getFileName();
         if (!m_output.open(QIODevice::WriteOnly)) {
-            downloadInfoLabel->setText(tr("Error opening save file: %1")
+            downloadInfoLabel->setText(tr("Error opening output file: %1")
                     .arg(m_output.errorString()));
             stop();
             emit statusChanged();
@@ -427,6 +427,7 @@ DownloadManager::DownloadManager(QWidget *parent)
     m_model = new DownloadModel(this);
     downloadsView->setModel(m_model);
     connect(cleanupButton, SIGNAL(clicked()), this, SLOT(cleanup()));
+    connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
     load();
 }
 
@@ -504,7 +505,7 @@ void DownloadManager::updateRow(DownloadItem *item)
     if (icon.isNull())
         icon = style()->standardIcon(QStyle::SP_FileIcon);
     item->fileIcon->setPixmap(icon.pixmap(48, 48));
-    
+
     int oldHeight = downloadsView->rowHeight(row);
     downloadsView->setRowHeight(row, qMax(oldHeight, item->minimumSizeHint().height()));
 
