@@ -66,7 +66,8 @@
 #include "browsermainwindow.h"
 #include "history.h"
 #include "tabbar.h"
-#include "urllineedit.h"
+#include "locationbar.h"
+#include "toolbarsearch.h"
 #include "webactionmapper.h"
 #include "webview.h"
 #include "webviewsearch.h"
@@ -96,12 +97,9 @@ TabWidget::TabWidget(QWidget *parent)
     , m_lineEdits(0)
     , m_tabBar(new TabBar(this))
 {
-#if QT_VERSION >= 0x040500
-    setDocumentMode(true);
-#endif
     setElideMode(Qt::ElideRight);
 
-    new QShortcut(QKeySequence("Ctrl+Shift+T"), this, SLOT(openLastTab()));
+    new QShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_T), this, SLOT(openLastTab()));
 
     connect(m_tabBar, SIGNAL(loadUrl(const QUrl&, TabWidget::Tab)),
             this, SLOT(loadUrl(const QUrl&, TabWidget::Tab)));
@@ -111,8 +109,15 @@ TabWidget::TabWidget(QWidget *parent)
     connect(m_tabBar, SIGNAL(closeOtherTabs(int)), this, SLOT(closeOtherTabs(int)));
     connect(m_tabBar, SIGNAL(reloadTab(int)), this, SLOT(reloadTab(int)));
     connect(m_tabBar, SIGNAL(reloadAllTabs()), this, SLOT(reloadAllTabs()));
+#if QT_VERSION < 0x040500
     connect(m_tabBar, SIGNAL(tabMoveRequested(int, int)), this, SLOT(moveTab(int, int)));
+#endif
     setTabBar(m_tabBar);
+#if QT_VERSION >= 0x040500
+    setDocumentMode(true);
+    connect(m_tabBar, SIGNAL(tabMoved(int, int)),
+            this, SLOT(moveTab(int, int)));
+#endif
 
     // Actions
     m_newTabAction = new QAction(tr("New &Tab"), this);
@@ -163,7 +168,7 @@ TabWidget::TabWidget(QWidget *parent)
 #if QT_VERSION >= 0x040500
     m_tabBar->setTabsClosable(true);
     connect(m_tabBar, SIGNAL(tabCloseRequested(int)),
-                      this, SLOT(closeTab(int)));
+            this, SLOT(closeTab(int)));
     m_tabBar->setSelectionBehaviorOnRemove(QTabBar::SelectPreviousTab);
 #else
     // corner buttons
@@ -213,6 +218,7 @@ void TabWidget::reloadTab(int index)
 
 void TabWidget::moveTab(int fromIndex, int toIndex)
 {
+#if QT_VERSION < 0x040500
     disconnect(this, SIGNAL(currentChanged(int)),
                this, SLOT(currentChanged(int)));
 
@@ -229,6 +235,11 @@ void TabWidget::moveTab(int fromIndex, int toIndex)
     connect(this, SIGNAL(currentChanged(int)),
             this, SLOT(currentChanged(int)));
     setCurrentIndex(toIndex);
+#else
+    QWidget *lineEdit = m_lineEdits->widget(fromIndex);
+    m_lineEdits->removeWidget(lineEdit);
+    m_lineEdits->insertWidget(toIndex, lineEdit);
+#endif
 }
 
 void TabWidget::addWebAction(QAction *action, QWebPage::WebAction webAction)
@@ -271,10 +282,11 @@ void TabWidget::currentChanged(int index)
     m_lineEdits->setCurrentIndex(index);
     emit loadProgress(webView->progress());
     emit showStatusBarMessage(webView->lastStatusBarText());
-    if (webView->url().isEmpty())
+    if (webView->url().isEmpty() && webView->hasFocus()) {
         m_lineEdits->currentWidget()->setFocus();
-    else
+    } else if (!webView->url().isEmpty()) {
         webView->setFocus();
+    }
 }
 
 QAction *TabWidget::newTabAction() const
@@ -319,10 +331,7 @@ WebView *TabWidget::currentWebView() const
 
 QLineEdit *TabWidget::lineEdit(int index) const
 {
-    UrlLineEdit *urlLineEdit = qobject_cast<UrlLineEdit*>(m_lineEdits->widget(index));
-    if (urlLineEdit)
-        return urlLineEdit->lineEdit();
-    return 0;
+    return qobject_cast<LocationBar*>(m_lineEdits->widget(index));
 }
 
 WebView *TabWidget::webView(int index) const
@@ -330,13 +339,24 @@ WebView *TabWidget::webView(int index) const
     QWidget *widget = this->widget(index);
     if (WebViewWithSearch *webViewWithSearch = qobject_cast<WebViewWithSearch*>(widget)) {
         return webViewWithSearch->m_webView;
-    } else {
+    } else if (widget) {
         // optimization to delay creating the first webview
         if (count() == 1) {
             TabWidget *that = const_cast<TabWidget*>(this);
             that->setUpdatesEnabled(false);
+            LocationBar *currentLocationBar = qobject_cast<LocationBar*>(m_lineEdits->widget(0));
+            bool giveBackFocus = currentLocationBar->hasFocus();
+            m_lineEdits->removeWidget(currentLocationBar);
+            m_lineEdits->addWidget(new QWidget());
             that->newTab();
             that->closeTab(0);
+            QWidget *newEmptyLineEdit = m_lineEdits->widget(0);
+            m_lineEdits->removeWidget(newEmptyLineEdit);
+            newEmptyLineEdit->deleteLater();
+            m_lineEdits->addWidget(currentLocationBar);
+            currentLocationBar->setWebView(currentWebView());
+            if (giveBackFocus)
+                currentLocationBar->setFocus();
             that->setUpdatesEnabled(true);
             return currentWebView();
         }
@@ -373,6 +393,17 @@ void TabWidget::newTab()
     makeNewTab(true);
 }
 
+BrowserMainWindow *TabWidget::mainWindow()
+{
+    QWidget *w = this->parentWidget();
+    while (w) {
+        if (BrowserMainWindow *mw = qobject_cast<BrowserMainWindow*>(w))
+            return mw;
+        w = w->parentWidget();
+    }
+    return 0;
+}
+
 WebView *TabWidget::makeNewTab(bool makeCurrent)
 {
     if (!makeCurrent) {
@@ -382,8 +413,7 @@ WebView *TabWidget::makeNewTab(bool makeCurrent)
     }
 
     // line edit
-    UrlLineEdit *urlLineEdit = new UrlLineEdit;
-    QLineEdit *lineEdit = urlLineEdit->lineEdit();
+    LocationBar *locationBar = new LocationBar;
     if (!m_lineEditCompleter && count() > 0) {
         HistoryCompletionModel *completionModel = new HistoryCompletionModel(this);
         completionModel->setSourceModel(BrowserApplication::historyManager()->historyFilterModel());
@@ -391,13 +421,18 @@ WebView *TabWidget::makeNewTab(bool makeCurrent)
         // Should this be in Qt by default?
         QAbstractItemView *popup = m_lineEditCompleter->popup();
         QListView *listView = qobject_cast<QListView*>(popup);
-        if (listView)
+        if (listView) {
+            // Urls are always LeftToRight
+            listView->setLayoutDirection(Qt::LeftToRight);
             listView->setUniformItemSizes(true);
+        }
     }
-    lineEdit->setCompleter(m_lineEditCompleter);
-    connect(lineEdit, SIGNAL(returnPressed()), this, SLOT(lineEditReturnPressed()));
-    m_lineEdits->addWidget(urlLineEdit);
-    m_lineEdits->setSizePolicy(lineEdit->sizePolicy());
+    locationBar->setCompleter(m_lineEditCompleter);
+    connect(locationBar, SIGNAL(returnPressed()), this, SLOT(lineEditReturnPressed()));
+    m_lineEdits->addWidget(locationBar);
+    m_lineEdits->setSizePolicy(locationBar->sizePolicy());
+
+    QWidget::setTabOrder(locationBar, qFindChild<ToolbarSearch*>(mainWindow()));
 
     // optimization to delay creating the more expensive WebView, history, etc
     if (count() == 0) {
@@ -408,7 +443,7 @@ WebView *TabWidget::makeNewTab(bool makeCurrent)
         emptyWidget->setAutoFillBackground(true);
         disconnect(this, SIGNAL(currentChanged(int)),
                    this, SLOT(currentChanged(int)));
-        addTab(emptyWidget, tr("(Untitled)"));
+        addTab(emptyWidget, tr("Untitled"));
         connect(this, SIGNAL(currentChanged(int)),
                 this, SLOT(currentChanged(int)));
         return 0;
@@ -416,7 +451,7 @@ WebView *TabWidget::makeNewTab(bool makeCurrent)
 
     // webview
     WebView *webView = new WebView;
-    urlLineEdit->setWebView(webView);
+    locationBar->setWebView(webView);
     connect(webView, SIGNAL(loadStarted()),
             this, SLOT(webViewLoadStarted()));
     connect(webView, SIGNAL(loadFinished(bool)),
@@ -441,12 +476,10 @@ WebView *TabWidget::makeNewTab(bool makeCurrent)
             this, SLOT(toolBarVisibilityChangeRequestedCheck(bool)));
 
     WebViewWithSearch *webViewWithSearch = new WebViewWithSearch(webView, this);
-    addTab(webViewWithSearch, tr("(Untitled)"));
+    addTab(webViewWithSearch, tr("Untitled"));
     if (makeCurrent)
         setCurrentWidget(webViewWithSearch);
 
-    QWidget::setTabOrder(this, urlLineEdit);
-
     // webview actions
     for (int i = 0; i < m_actions.count(); ++i) {
         WebActionMapper *mapper = m_actions[i];
@@ -597,11 +630,10 @@ QLabel *TabWidget::animationLabel(int index, bool addMovie)
         loadingAnimation = new QLabel(this);
     }
     if (addMovie && !loadingAnimation->movie()) {
-        QMovie *movie = new QMovie(":loading.gif", QByteArray(), loadingAnimation);
+        QMovie *movie = new QMovie(QLatin1String(":loading.gif"), QByteArray(), loadingAnimation);
         loadingAnimation->setMovie(movie);
         movie->start();
     }
-    loadingAnimation->show();
     m_tabBar->setTabButton(index, side, 0);
     m_tabBar->setTabButton(index, side, loadingAnimation);
     return loadingAnimation;
@@ -633,6 +665,11 @@ void TabWidget::webViewLoadFinished()
         QLabel *label = animationLabel(index, true);
         if (label->movie())
             label->movie()->stop();
+#if defined(Q_WS_MAC)
+        QTabBar::ButtonPosition side = m_tabBar->freeSide();
+        m_tabBar->setTabButton(index, side, 0);
+        delete label;
+#endif
     }
 #endif
     webViewIconChanged();
@@ -643,15 +680,17 @@ void TabWidget::webViewIconChanged()
     WebView *webView = qobject_cast<WebView*>(sender());
     int index = webViewIndex(webView);
     if (-1 != index) {
-        QIcon icon = BrowserApplication::instance()->icon(webView->url());
 #if QT_VERSION >= 0x040500
+#if !defined(Q_WS_MAC)
+        QIcon icon = BrowserApplication::instance()->icon(webView->url());
         QLabel *label = animationLabel(index, false);
         QMovie *movie = label->movie();
         delete movie;
         label->setMovie(0);
         label->setPixmap(icon.pixmap(16, 16));
-        label->show();
+#endif
 #else
+        QIcon icon = BrowserApplication::instance()->icon(webView->url());
         setTabIcon(index, icon);
 #endif
     }
@@ -828,7 +867,7 @@ bool TabWidget::restoreState(const QByteArray &state)
     QStringList openTabs;
     stream >> openTabs;
     for (int i = 0; i < openTabs.count(); ++i)
-        loadUrl(openTabs.at(i), i == 0 ? CurrentTab : NewTab);
+        loadUrl(openTabs.at(i), i == 0 && currentWebView()->url() == QUrl() ? CurrentTab : NewTab);
 
     int currentTab;
     stream >> currentTab;
